@@ -48,10 +48,6 @@ GtkMenuItem *         eel_gtk_menu_append_separator                   (GtkMenu
 GtkMenuItem *         eel_gtk_menu_insert_separator                   (GtkMenu              *menu,
 								       int                   index);
 
-/* GtkTreeView */
-void                  eel_gtk_tree_view_set_activate_on_single_click  (GtkTreeView               *tree_view,
-								       gboolean                   should_activate);
-
 /* GtkMessageDialog */
 void                  eel_gtk_message_dialog_set_details_label        (GtkMessageDialog          *dialog,
 								       const gchar               *details_text);
